@@ -76,6 +76,13 @@ from snaptrade_client.model.manual_trade_form_with_options import ManualTradeFor
 from snaptrade_client.model.manual_trade_impact import ManualTradeImpact
 from snaptrade_client.model.manual_trade_replace_form import ManualTradeReplaceForm
 from snaptrade_client.model.manual_trade_symbol import ManualTradeSymbol
+from snaptrade_client.model.mleg_action_strict import MlegActionStrict
+from snaptrade_client.model.mleg_instrument_type import MlegInstrumentType
+from snaptrade_client.model.mleg_leg import MlegLeg
+from snaptrade_client.model.mleg_order_response import MlegOrderResponse
+from snaptrade_client.model.mleg_order_type_strict import MlegOrderTypeStrict
+from snaptrade_client.model.mleg_trade_form import MlegTradeForm
+from snaptrade_client.model.mleg_trading_instrument import MlegTradingInstrument
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.model.model401_failed_request_response import Model401FailedRequestResponse
 from snaptrade_client.model.model402_brokerage_auth_already_disabled_exception import Model402BrokerageAuthAlreadyDisabledException
@@ -125,6 +132,7 @@ from snaptrade_client.model.reporting_frequency import ReportingFrequency
 from snaptrade_client.model.security_type import SecurityType
 from snaptrade_client.model.security_type_id import SecurityTypeID
 from snaptrade_client.model.session_event import SessionEvent
+from snaptrade_client.model.simple_order_form import SimpleOrderForm
 from snaptrade_client.model.simple_order_preview import SimpleOrderPreview
 from snaptrade_client.model.simple_order_preview_estimated_fee import SimpleOrderPreviewEstimatedFee
 from snaptrade_client.model.snap_trade_holdings_account import SnapTradeHoldingsAccount
