@@ -241,6 +241,7 @@ class BaseApi(api_client.Api):
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        symbol: typing.Optional[str] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
         query_params: typing.Optional[dict] = {},
@@ -258,6 +259,8 @@ class BaseApi(api_client.Api):
             _body["time_in_force"] = time_in_force
         if price is not None:
             _body["price"] = price
+        if symbol is not None:
+            _body["symbol"] = symbol
         if stop is not None:
             _body["stop"] = stop
         if units is not None:
@@ -554,6 +557,7 @@ class ReplaceOrder(BaseApi):
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        symbol: typing.Optional[str] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
         query_params: typing.Optional[dict] = {},
@@ -576,6 +580,7 @@ class ReplaceOrder(BaseApi):
             user_id=user_id,
             user_secret=user_secret,
             price=price,
+            symbol=symbol,
             stop=stop,
             units=units,
         )
@@ -597,6 +602,7 @@ class ReplaceOrder(BaseApi):
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        symbol: typing.Optional[str] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
         query_params: typing.Optional[dict] = {},
@@ -618,6 +624,7 @@ class ReplaceOrder(BaseApi):
             user_id=user_id,
             user_secret=user_secret,
             price=price,
+            symbol=symbol,
             stop=stop,
             units=units,
         )
@@ -641,6 +648,7 @@ class ApiForpatch(BaseApi):
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        symbol: typing.Optional[str] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
         query_params: typing.Optional[dict] = {},
@@ -663,6 +671,7 @@ class ApiForpatch(BaseApi):
             user_id=user_id,
             user_secret=user_secret,
             price=price,
+            symbol=symbol,
             stop=stop,
             units=units,
         )
@@ -684,6 +693,7 @@ class ApiForpatch(BaseApi):
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        symbol: typing.Optional[str] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
         query_params: typing.Optional[dict] = {},
@@ -705,6 +715,7 @@ class ApiForpatch(BaseApi):
             user_id=user_id,
             user_secret=user_secret,
             price=price,
+            symbol=symbol,
             stop=stop,
             units=units,
         )
