@@ -13,7 +13,7 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.balance import Balance
 from snaptrade_client.type.position import Position
@@ -26,10 +26,11 @@ class RequiredAccountHoldings(TypedDict):
 class OptionalAccountHoldings(TypedDict, total=False):
     account: SnapTradeHoldingsAccount
 
-    balances: typing.List[Balance]
+    balances: typing.Optional[typing.List[Balance]]
 
-    positions: typing.List[Position]
+    positions: typing.Optional[typing.List[Position]]
 
+    # WARNING: This property is deprecated
     total_value: SnapTradeHoldingsTotalValue
 
 class AccountHoldings(RequiredAccountHoldings, OptionalAccountHoldings):
